clear

use "Data/all_data_followup.dta"

/* Identify Attrited Subjects */
gen attrit = 0
replace attrit = 1 if id == 169 | id == 271 | id == 365 | id == 219 | id == 349

/* Identify Problematic Subjects */
drop if choice2 == .
bysort id: gen obscount = _N
egen temp = total(choice2), by(id round)
gen temp2 = (temp == 540)
egen count60 = total(temp2), by(id)
capture drop temp2
gen temp2 = (temp == 0)
egen count0 = total(temp2), by(id)


/* Identify Insufficient Variation */
capture drop sdc
egen sdc = sd(choice2), by(round id)

capture drop temp
gen temp = (sdc ==0)

capture drop countsdc20
egen countsdc20 = total(temp), by(id)

capture drop sdc
egen sdc = sd(choice1), by(round id)

capture drop temp
gen temp = (sdc ==0)

capture drop countsdc10
egen countsdc10 = total(temp), by(id)

/* Price Ratio */
gen pratio = discountrate

gen logpratio = log(pratio)

* Generate Consumption Ratios */

gen min = 10
replace min = 5 if money ==1

gen cratio = (choice1+min)/(choice2+min)
gen logcratio = log(cratio)

/* Censored Observation: Corner Solution */
capture drop cnsrd
gen cnsrd = 0
replace cnsrd = -1 if choice2 == 0
replace cnsrd = 1 if choice2 == 60 & money == 0
replace cnsrd = 1 if choice2 == 20 & money == 1

capture drop interior
gen interior = 0
replace interior = 1 if cnsrd == 0
replace interior = . if choice2 == .

egen totinterior = total(interior), by(id)


/* Budget Shares */
capture drop bs
gen bs = choice1*pratio
replace bs = bs/60 if money== 0
replace bs = bs/20 if money== 1


/* Difference in Budget Shares */
capture drop bsdiff
by id discountrate (round), sort: gen bsdiff = bs[2] - bs[1]

capture drop bs2
by id discountrate (round), sort: gen bs2 = bs[2] 

/* Capture All Budget Share Differences */
by id round (discountrate), sort: gen bsdiff1 = bsdiff[1] 
by id round (discountrate), sort: gen bsdiff2 = bsdiff[2] 
by id round (discountrate), sort: gen bsdiff3 = bsdiff[3] 
by id round (discountrate), sort: gen bsdiff4 = bsdiff[4] 
by id round (discountrate), sort: gen bsdiff5 = bsdiff[5] 
by id round (discountrate), sort: gen bsdiff6 = bsdiff[6] 
by id round (discountrate), sort: gen bsdiff7 = bsdiff[7] 
by id round (discountrate), sort: gen bsdiff8 = bsdiff[8] 
by id round (discountrate), sort: gen bsdiff9 = bsdiff[9] 


/* Present Bias */
gen pb = ((bsdiff <0 & money ==0) |(bsdiff>0 &money == 1))
replace pb = . if bsdiff ==.

gen fb = ((bsdiff >0 & money ==0) |(bsdiff<0 &money == 1))
replace fb = . if bsdiff ==.  

gen dc = (bsdiff == 0)
replace dc = . if bsdiff ==.  



/* Interval Limits on Cost Ratio */
gen logcratiolow = logcratio
replace logcratiolow = . if  cnsrd == 1
gen logcratiohigh = logcratio
replace logcratiohigh = . if cnsrd == -1

/* Time Variables */
gen t0 = (round ==2)

gen k = 7


log on
/*** Replication Exercise Analyses */
/* Replication Exercise Non-parametric Details */
xi: reg choice2 i.discountrate t0 if obscount == 18 & attrit == 0 & money == 0, clu(id)
test t0
xi: reg choice2 i.discountrate t0 if obscount == 18 & attrit == 0 & money == 1, clu(id)
test t0
log off

/* Aggregate Estimators */
/* Money */
intreg logcratiolow logcratiohigh t0 k logpratio if money == 1 & obscount == 18 & attrit == 0 , nocons clu(id)
nlcom (alpha: (1/_b[logpratio]) + 1) (beta: exp(_b[t0]/_b[logpratio])) (delta: (exp(_b[k]/_b[logpratio]))^7), post
est store col1
test beta = 1
scalar b1 = round(r(chi2), .01)
scalar b1p = round(r(p), .001)

/* Work */
intreg logcratiolow logcratiohigh t0 k logpratio if money == 0 & obscount == 18 & attrit == 0 , nocons clu(id)
nlcom (gamma: (1/_b[logpratio]) + 1) (beta: exp(_b[t0]/_b[logpratio])) (delta: (exp(_b[k]/_b[logpratio]))^7), post
est store col2
test beta = 1
scalar b2= round(r(chi2), .01)
scalar b2p = round(r(p), .001)


/* Combination */
xi: intreg logcratiolow logcratiohigh i.money*t0 i.money*logpratio if  obscount == 18 & attrit == 0, clu(id) het(money) 
nlcom (betawork: exp(_b[t0]/_b[logpratio])) (betamoney: exp((_b[t0]+ _b[_ImonXt0_1]) /(_b[logpratio] + _b[_ImonXlogpr_1]) )), post
test betawork = betamoney
scalar b3 = round(r(chi2), .01)
scalar b3p = round(r(p), .001)


log on
/* Table 4: Replication Exercise Parameter Estimates */
estout col1 col2 , cells(b(fmt(%9.3f)) se(par fmt(%9.3f))) style(tex) stats(N ll r2) order(beta delta alpha gamma)
disp "&" b1 "&" b2  "\\"
disp "& (p =" b1p ")&( p =" b2p ")\\"
disp "&" b3  "\\"
disp "& (p =" b3p ")\\"
log off

log on
/** Table A4 : Present Bias By Interest Rate Replication Exercise**/
capture drop temp
egen temp = group(discountrate) 
/* Panel A: Effort Choices */
foreach x of numlist  1  2 3 4 5 6 7 8 9 {
qui su discountrate if temp == `x'
local rate = round(r(mean), .001)
qui ttest bs = bs2 if temp == `x' & round == 1 & money == 0 & attrit == 0 & obscount == 18
local initm= round(r(mu_1), .001)
local initsd= round(r(sd_1), .001)
local subm= round(r(mu_2), .001)
local subsd= round(r(sd_2), .001)
local tstat= round(r(t), .001)
local pval= round(r(p), .001)
qui su pb  if temp == `x' & round == 1 & money == 0 & attrit == 0 & obscount == 18
local pbprop = round(r(mean), .001)
qui su dc if temp == `x' & round == 1 & money == 0 & attrit == 0 & obscount == 18
local dcprop = round(r(mean), .001)
qui su fb if temp == `x' & round == 1 & money == 0 & attrit == 0 & obscount == 18
local fbprop = round(r(mean), .001)
disp `rate' "&" `initm' "&" `subm' " & " `tstat' "&" `pbprop' "&" `dcprop' " & " `fbprop' "\\"
disp  "&(" `initsd' ")&(" `subsd' ") & (p=" `pval' ")&" "\\"
}

reg bs t0 if obscount == 18 & attrit == 0 & money == 0, clu(id)
test t0

/* Panel B: Money Choices */ 
foreach x of numlist  1  2 3 4 5 6 7 8 9 {
qui su discountrate if temp == `x'
local rate = round(r(mean), .001)
qui ttest bs = bs2 if temp == `x' & round == 1 & money == 1 & attrit == 0 & obscount == 18
local initm= round(r(mu_1), .001)
local initsd= round(r(sd_1), .001)
local subm= round(r(mu_2), .001)
local subsd= round(r(sd_2), .001)
local tstat= round(r(t), .001)
local pval= round(r(p), .001)
qui su pb  if temp == `x' & round == 1 & money == 1 & attrit == 0 & obscount == 18
local pbprop = round(r(mean), .001)
qui su dc if temp == `x' & round == 1 & money == 1 & attrit == 0 & obscount == 18
local dcprop = round(r(mean), .001)
qui su fb if temp == `x' & round == 1 & money == 1 & attrit == 0 & obscount == 18
local fbprop = round(r(mean), .001)
disp `rate' "&" `initm' "&" `subm' " & " `tstat' "&" `pbprop' "&" `dcprop' " & " `fbprop' "\\"
disp  "&(" `initsd' ")&(" `subsd' ") & (p=" `pval' ")&" "\\"
}

reg bs t0 if obscount == 18 & attrit == 0 & money == 0, clu(id)
test t0
log off


/* Aggregate Estimators Removing Insufficient Variation */
/* Money */
intreg logcratiolow logcratiohigh t0 k logpratio if money == 1 & obscount == 18 & attrit == 0 & countsdc10 ==0 & countsdc20==0 , nocons clu(id)
nlcom (alpha: (1/_b[logpratio]) + 1) (beta: exp(_b[t0]/_b[logpratio])) (delta: (exp(_b[k]/_b[logpratio]))^7), post
est store col1
test beta = 1
scalar b1 = round(r(chi2), .01)
scalar b1p = round(r(p), .001)

/* Work */
intreg logcratiolow logcratiohigh t0 k logpratio if money == 0 & obscount == 18 & attrit == 0 & countsdc10 ==0 & countsdc20==0 , nocons clu(id)
nlcom (gamma: (1/_b[logpratio]) + 1) (beta: exp(_b[t0]/_b[logpratio])) (delta: (exp(_b[k]/_b[logpratio]))^7), post
est store col2
test beta = 1
scalar b2= round(r(chi2), .01)
scalar b2p = round(r(p), .001)


/* Combination */
xi: intreg logcratiolow logcratiohigh i.money*t0 i.money*logpratio if  obscount == 18 & attrit == 0 & countsdc10 ==0 & countsdc20==0 , clu(id) het(money) 
nlcom (betawork: exp(_b[t0]/_b[logpratio])) (betamoney: exp((_b[t0]+ _b[_ImonXt0_1]) /(_b[logpratio] + _b[_ImonXlogpr_1]) )), post
test betawork = betamoney
scalar b3 = round(r(chi2), .01)
scalar b3p = round(r(p), .001)




log on
/* Table A13: Replication Exercise Parameter Estimates, Restricted Sample */
estout col1 col2 , cells(b(fmt(%9.3f)) se(par fmt(%9.3f))) style(tex) stats(N ll r2) order(beta delta alpha gamma)
disp "&" b1 "&" b2  "\\"
disp "& (p =" b1p ")&( p =" b2p ")\\"
disp "&" b3  "\\"
disp "& (p =" b3p ")\\"
log off




/* Figure 8: Between Subjects Replication Exercise */
capture drop temp
egen temp = group(discountrate money round)

xi: reg choice2 i.temp if obscount == 18 & attrit ==0 , clu(id)
capture drop meanchoice 
predict meanchoice
capture drop sechoice 
predict sechoice, stdp
capture drop choicelow
gen choicelow = meanchoice - 1*sechoice
capture drop choicehigh
gen choicehigh = meanchoice + 1*sechoice

twoway (rcap choicelow choicehigh discountrate if round==1 |round == 2) (connected meanchoice discountrate if round==1, sort)  (connected meanchoice discountrate if round==2, sort) if money == 0 & id == 75,  legend(order(2 "Week 1 Allocation" "Mean" 3 "Week 2 Allocation" "Mean" 1 "SE") row(1) off ) xtitle("P" "(from Pa{sub:2}+a{sub:3}=60)") ytitle("Tasks Allocated to Later Date") title("Panel B: Effort") ylab(15(5)40) scheme(s1mono) 
graph save "Output/panelB.gph", replace

twoway (rcap choicelow choicehigh discountrate if round==1 |round == 2) (connected meanchoice discountrate if round==1, sort)  (connected meanchoice discountrate if round==2, sort) if money == 1 & id == 5,  legend(order(2 "Week 1 Allocation" "Mean" 3 "Week 2 Allocation" "Mean" 1 "SE") row(1) off ) xtitle("P" "(from Pa{sub:2}+a{sub:3}=20)") ytitle("Dollars Allocated to Later Date") title("Panel A: Money") ylab(0(5)20) scheme(s1mono) 
graph save "Output/panelA.gph", replace

graph combine "Output/panelA.gph" "Output/panelB.gph", xcommon scheme(s1mono) row(2) xsize(8.5) ysize(11)
graph export "Output/replication.pdf", replace



/* Individual Estimators */
set matsize 1000
capture drop uniqid
egen uniqid = group(id) if money == 0 & obscount==18
xi: reg logcratio i.t0*i.uniqid logpratio if money ==0 
nlcom (beta1: exp(_b[_It0_1]/_b[logpratio])) /// 
(beta2: exp((_b[_It0_1] +  _b[_It0Xuni_1_2])/_b[logpratio])) ///
(beta3: exp((_b[_It0_1] +  _b[_It0Xuni_1_3])/_b[logpratio])) ///
(beta4: exp((_b[_It0_1] +  _b[_It0Xuni_1_4])/_b[logpratio])) ///
(beta5: exp((_b[_It0_1] +  _b[_It0Xuni_1_5])/_b[logpratio])) ///
(beta6: exp((_b[_It0_1] +  _b[_It0Xuni_1_6])/_b[logpratio])) ///
(beta7: exp((_b[_It0_1] +  _b[_It0Xuni_1_7])/_b[logpratio])) ///
(beta8: exp((_b[_It0_1] +  _b[_It0Xuni_1_8])/_b[logpratio])) ///
(beta9: exp((_b[_It0_1] +  _b[_It0Xuni_1_9])/_b[logpratio])) ///
(beta10: exp((_b[_It0_1] +  _b[_It0Xuni_1_10])/_b[logpratio])) ///
(beta11: exp((_b[_It0_1] +  _b[_It0Xuni_1_11])/_b[logpratio])) ///
(beta12: exp((_b[_It0_1] +  _b[_It0Xuni_1_12])/_b[logpratio])) ///
(beta13: exp((_b[_It0_1] +  _b[_It0Xuni_1_13])/_b[logpratio])) ///
(beta14: exp((_b[_It0_1] +  _b[_It0Xuni_1_14])/_b[logpratio])) ///
(beta15: exp((_b[_It0_1] +  _b[_It0Xuni_1_15])/_b[logpratio])) ///
(beta16: exp((_b[_It0_1] +  _b[_It0Xuni_1_16])/_b[logpratio])) ///
(beta17: exp((_b[_It0_1] +  _b[_It0Xuni_1_17])/_b[logpratio])) ///
(beta18: exp((_b[_It0_1] +  _b[_It0Xuni_1_18])/_b[logpratio])) ///
(beta19: exp((_b[_It0_1] +  _b[_It0Xuni_1_19])/_b[logpratio])) ///
(beta20: exp((_b[_It0_1] +  _b[_It0Xuni_1_20])/_b[logpratio])) ///
(beta21: exp((_b[_It0_1] +  _b[_It0Xuni_1_21])/_b[logpratio])) ///
(beta22: exp((_b[_It0_1] +  _b[_It0Xuni_1_22])/_b[logpratio])) ///
(beta23: exp((_b[_It0_1] +  _b[_It0Xuni_1_23])/_b[logpratio])) ///
(beta24: exp((_b[_It0_1] +  _b[_It0Xuni_1_24])/_b[logpratio])) ///
(beta25: exp((_b[_It0_1] +  _b[_It0Xuni_1_25])/_b[logpratio])) ///
(beta26: exp((_b[_It0_1] +  _b[_It0Xuni_1_26])/_b[logpratio])) ///
(beta27: exp((_b[_It0_1] +  _b[_It0Xuni_1_27])/_b[logpratio])) ///
(beta28: exp((_b[_It0_1] +  _b[_It0Xuni_1_28])/_b[logpratio])) ///
(beta29: exp((_b[_It0_1] +  _b[_It0Xuni_1_29])/_b[logpratio])) ///
(beta30: exp((_b[_It0_1] +  _b[_It0Xuni_1_30])/_b[logpratio])) ///
(beta31: exp((_b[_It0_1] +  _b[_It0Xuni_1_31])/_b[logpratio])) ///
(beta32: exp((_b[_It0_1] +  _b[_It0Xuni_1_32])/_b[logpratio])) ///
(beta33: exp((_b[_It0_1] +  _b[_It0Xuni_1_33])/_b[logpratio])) ///
(beta34: exp((_b[_It0_1] +  _b[_It0Xuni_1_34])/_b[logpratio])) ///
(beta35: exp((_b[_It0_1] +  _b[_It0Xuni_1_35])/_b[logpratio])) ///
(beta36: exp((_b[_It0_1] +  _b[_It0Xuni_1_36])/_b[logpratio])) ///
(beta37: exp((_b[_It0_1] +  _b[_It0Xuni_1_37])/_b[logpratio])) ///
(beta38: exp((_b[_It0_1] +  _b[_It0Xuni_1_38])/_b[logpratio])) ///
(beta39: exp((_b[_It0_1] +  _b[_It0Xuni_1_39])/_b[logpratio])) ///
(beta40: exp((_b[_It0_1] +  _b[_It0Xuni_1_40])/_b[logpratio])) ///
(beta41: exp((_b[_It0_1] +  _b[_It0Xuni_1_41])/_b[logpratio])) ///
(beta42: exp((_b[_It0_1] +  _b[_It0Xuni_1_42])/_b[logpratio])) ///
(beta43: exp((_b[_It0_1] +  _b[_It0Xuni_1_43])/_b[logpratio])) ///
(beta44: exp((_b[_It0_1] +  _b[_It0Xuni_1_44])/_b[logpratio])) ///
(beta45: exp((_b[_It0_1] +  _b[_It0Xuni_1_45])/_b[logpratio])) ///
(beta46: exp((_b[_It0_1] +  _b[_It0Xuni_1_46])/_b[logpratio])) ///
(beta47: exp((_b[_It0_1] +  _b[_It0Xuni_1_47])/_b[logpratio])) ///
(beta48: exp((_b[_It0_1] +  _b[_It0Xuni_1_48])/_b[logpratio])) ///
(beta49: exp((_b[_It0_1] +  _b[_It0Xuni_1_49])/_b[logpratio])) ///
(beta50: exp((_b[_It0_1] +  _b[_It0Xuni_1_50])/_b[logpratio])) ///
(beta51: exp((_b[_It0_1] +  _b[_It0Xuni_1_51])/_b[logpratio])) ///
(beta52: exp((_b[_It0_1] +  _b[_It0Xuni_1_52])/_b[logpratio])) ///
(beta53: exp((_b[_It0_1] +  _b[_It0Xuni_1_53])/_b[logpratio])) ///
(beta54: exp((_b[_It0_1] +  _b[_It0Xuni_1_54])/_b[logpratio])) ///
(beta55: exp((_b[_It0_1] +  _b[_It0Xuni_1_55])/_b[logpratio])) ///
(beta56: exp((_b[_It0_1] +  _b[_It0Xuni_1_56])/_b[logpratio])) ///
(beta57: exp((_b[_It0_1] +  _b[_It0Xuni_1_57])/_b[logpratio])) ///
(beta58: exp((_b[_It0_1] +  _b[_It0Xuni_1_58])/_b[logpratio])) ///
(beta59: exp((_b[_It0_1] +  _b[_It0Xuni_1_59])/_b[logpratio])) ///
(beta60: exp((_b[_It0_1] +  _b[_It0Xuni_1_60])/_b[logpratio])) ///
(beta61: exp((_b[_It0_1] +  _b[_It0Xuni_1_61])/_b[logpratio])) ///
(beta62: exp((_b[_It0_1] +  _b[_It0Xuni_1_62])/_b[logpratio])) ///
(beta63: exp((_b[_It0_1] +  _b[_It0Xuni_1_63])/_b[logpratio])) ///
(beta64: exp((_b[_It0_1] +  _b[_It0Xuni_1_64])/_b[logpratio])) ///
(beta65: exp((_b[_It0_1] +  _b[_It0Xuni_1_65])/_b[logpratio])) ///
(beta66: exp((_b[_It0_1] +  _b[_It0Xuni_1_66])/_b[logpratio])) ///
(beta67: exp((_b[_It0_1] +  _b[_It0Xuni_1_67])/_b[logpratio])) ///
(beta68: exp((_b[_It0_1] +  _b[_It0Xuni_1_68])/_b[logpratio])) ///
(beta69: exp((_b[_It0_1] +  _b[_It0Xuni_1_69])/_b[logpratio])) ///
(beta70: exp((_b[_It0_1] +  _b[_It0Xuni_1_70])/_b[logpratio])) ///
(beta71: exp((_b[_It0_1] +  _b[_It0Xuni_1_71])/_b[logpratio])) ///
(beta72: exp((_b[_It0_1] +  _b[_It0Xuni_1_72])/_b[logpratio])) ///
(beta73: exp((_b[_It0_1] +  _b[_It0Xuni_1_73])/_b[logpratio])) ///
(beta74: exp((_b[_It0_1] +  _b[_It0Xuni_1_74])/_b[logpratio])) ///
(beta75: exp((_b[_It0_1] +  _b[_It0Xuni_1_75])/_b[logpratio])) ///
(beta76: exp((_b[_It0_1] +  _b[_It0Xuni_1_76])/_b[logpratio])) ///
(beta77: exp((_b[_It0_1] +  _b[_It0Xuni_1_77])/_b[logpratio])) ///
(beta78: exp((_b[_It0_1] +  _b[_It0Xuni_1_78])/_b[logpratio])) ///
(beta79: exp((_b[_It0_1] +  _b[_It0Xuni_1_79])/_b[logpratio])) ///
(beta80: exp((_b[_It0_1] +  _b[_It0Xuni_1_80])/_b[logpratio])) ///
(beta81: exp((_b[_It0_1] +  _b[_It0Xuni_1_81])/_b[logpratio])) ///
(beta82: exp((_b[_It0_1] +  _b[_It0Xuni_1_82])/_b[logpratio])) ///
(beta83: exp((_b[_It0_1] +  _b[_It0Xuni_1_83])/_b[logpratio])) ///
(beta84: exp((_b[_It0_1] +  _b[_It0Xuni_1_84])/_b[logpratio])) ///
(beta85: exp((_b[_It0_1] +  _b[_It0Xuni_1_85])/_b[logpratio])) ///
(beta86: exp((_b[_It0_1] +  _b[_It0Xuni_1_86])/_b[logpratio])) ///
(beta87: exp((_b[_It0_1] +  _b[_It0Xuni_1_87])/_b[logpratio])) ///
(beta88: exp((_b[_It0_1] +  _b[_It0Xuni_1_88])/_b[logpratio])) ///
(beta89: exp((_b[_It0_1] +  _b[_It0Xuni_1_89])/_b[logpratio])) ///
(beta90: exp((_b[_It0_1] +  _b[_It0Xuni_1_90])/_b[logpratio])) ///
(beta91: exp((_b[_It0_1] +  _b[_It0Xuni_1_91])/_b[logpratio])) ///
(beta92: exp((_b[_It0_1] +  _b[_It0Xuni_1_92])/_b[logpratio])) ///
(beta93: exp((_b[_It0_1] +  _b[_It0Xuni_1_93])/_b[logpratio])) ///
(beta94: exp((_b[_It0_1] +  _b[_It0Xuni_1_94])/_b[logpratio])) ///
(beta95: exp((_b[_It0_1] +  _b[_It0Xuni_1_95])/_b[logpratio])) ///
(beta96: exp((_b[_It0_1] +  _b[_It0Xuni_1_96])/_b[logpratio])) ///
(beta97: exp((_b[_It0_1] +  _b[_It0Xuni_1_97])/_b[logpratio])) ///
(beta98: exp((_b[_It0_1] +  _b[_It0Xuni_1_98])/_b[logpratio])), post


/* Match Up Beta Estimates to Individuals */
capture drop betai
gen betai = .


forvalues i = 1(1)98 {
qui replace betai = _b[beta`i'] if uniqid == `i'
disp `i'
}

/* Redo for Money */
capture drop uniqid
egen uniqid = group(id) if money == 1 & obscount==18
xi: reg logcratio  i.t0*i.uniqid logpratio if money ==1, r
nlcom (beta1: exp(_b[_It0_1]/_b[logpratio])) /// 
(beta2: exp((_b[_It0_1] +  _b[_It0Xuni_1_2])/_b[logpratio])) ///
(beta3: exp((_b[_It0_1] +  _b[_It0Xuni_1_3])/_b[logpratio])) ///
(beta4: exp((_b[_It0_1] +  _b[_It0Xuni_1_4])/_b[logpratio])) ///
(beta5: exp((_b[_It0_1] +  _b[_It0Xuni_1_5])/_b[logpratio])) ///
(beta6: exp((_b[_It0_1] +  _b[_It0Xuni_1_6])/_b[logpratio])) ///
(beta7: exp((_b[_It0_1] +  _b[_It0Xuni_1_7])/_b[logpratio])) ///
(beta8: exp((_b[_It0_1] +  _b[_It0Xuni_1_8])/_b[logpratio])) ///
(beta9: exp((_b[_It0_1] +  _b[_It0Xuni_1_9])/_b[logpratio])) ///
(beta10: exp((_b[_It0_1] +  _b[_It0Xuni_1_10])/_b[logpratio])) ///
(beta11: exp((_b[_It0_1] +  _b[_It0Xuni_1_11])/_b[logpratio])) ///
(beta12: exp((_b[_It0_1] +  _b[_It0Xuni_1_12])/_b[logpratio])) ///
(beta13: exp((_b[_It0_1] +  _b[_It0Xuni_1_13])/_b[logpratio])) ///
(beta14: exp((_b[_It0_1] +  _b[_It0Xuni_1_14])/_b[logpratio])) ///
(beta15: exp((_b[_It0_1] +  _b[_It0Xuni_1_15])/_b[logpratio])) ///
(beta16: exp((_b[_It0_1] +  _b[_It0Xuni_1_16])/_b[logpratio])) ///
(beta17: exp((_b[_It0_1] +  _b[_It0Xuni_1_17])/_b[logpratio])) ///
(beta18: exp((_b[_It0_1] +  _b[_It0Xuni_1_18])/_b[logpratio])) ///
(beta19: exp((_b[_It0_1] +  _b[_It0Xuni_1_19])/_b[logpratio])) ///
(beta20: exp((_b[_It0_1] +  _b[_It0Xuni_1_20])/_b[logpratio])) ///
(beta21: exp((_b[_It0_1] +  _b[_It0Xuni_1_21])/_b[logpratio])) ///
(beta22: exp((_b[_It0_1] +  _b[_It0Xuni_1_22])/_b[logpratio])) ///
(beta23: exp((_b[_It0_1] +  _b[_It0Xuni_1_23])/_b[logpratio])) ///
(beta24: exp((_b[_It0_1] +  _b[_It0Xuni_1_24])/_b[logpratio])) ///
(beta25: exp((_b[_It0_1] +  _b[_It0Xuni_1_25])/_b[logpratio])) ///
(beta26: exp((_b[_It0_1] +  _b[_It0Xuni_1_26])/_b[logpratio])) ///
(beta27: exp((_b[_It0_1] +  _b[_It0Xuni_1_27])/_b[logpratio])) ///
(beta28: exp((_b[_It0_1] +  _b[_It0Xuni_1_28])/_b[logpratio])) ///
(beta29: exp((_b[_It0_1] +  _b[_It0Xuni_1_29])/_b[logpratio])) ///
(beta30: exp((_b[_It0_1] +  _b[_It0Xuni_1_30])/_b[logpratio])) ///
(beta31: exp((_b[_It0_1] +  _b[_It0Xuni_1_31])/_b[logpratio])) ///
(beta32: exp((_b[_It0_1] +  _b[_It0Xuni_1_32])/_b[logpratio])) ///
(beta33: exp((_b[_It0_1] +  _b[_It0Xuni_1_33])/_b[logpratio])) ///
(beta34: exp((_b[_It0_1] +  _b[_It0Xuni_1_34])/_b[logpratio])) ///
(beta35: exp((_b[_It0_1] +  _b[_It0Xuni_1_35])/_b[logpratio])) ///
(beta36: exp((_b[_It0_1] +  _b[_It0Xuni_1_36])/_b[logpratio])) ///
(beta37: exp((_b[_It0_1] +  _b[_It0Xuni_1_37])/_b[logpratio])) ///
(beta38: exp((_b[_It0_1] +  _b[_It0Xuni_1_38])/_b[logpratio])) ///
(beta39: exp((_b[_It0_1] +  _b[_It0Xuni_1_39])/_b[logpratio])) ///
(beta40: exp((_b[_It0_1] +  _b[_It0Xuni_1_40])/_b[logpratio])) ///
(beta41: exp((_b[_It0_1] +  _b[_It0Xuni_1_41])/_b[logpratio])) ///
(beta42: exp((_b[_It0_1] +  _b[_It0Xuni_1_42])/_b[logpratio])) ///
(beta43: exp((_b[_It0_1] +  _b[_It0Xuni_1_43])/_b[logpratio])) ///
(beta44: exp((_b[_It0_1] +  _b[_It0Xuni_1_44])/_b[logpratio])) ///
(beta45: exp((_b[_It0_1] +  _b[_It0Xuni_1_45])/_b[logpratio])) ///
(beta46: exp((_b[_It0_1] +  _b[_It0Xuni_1_46])/_b[logpratio])) ///
(beta47: exp((_b[_It0_1] +  _b[_It0Xuni_1_47])/_b[logpratio])) ///
(beta48: exp((_b[_It0_1] +  _b[_It0Xuni_1_48])/_b[logpratio])) ///
(beta49: exp((_b[_It0_1] +  _b[_It0Xuni_1_49])/_b[logpratio])) ///
(beta50: exp((_b[_It0_1] +  _b[_It0Xuni_1_50])/_b[logpratio])) ///
(beta51: exp((_b[_It0_1] +  _b[_It0Xuni_1_51])/_b[logpratio])) ///
(beta52: exp((_b[_It0_1] +  _b[_It0Xuni_1_52])/_b[logpratio])) ///
(beta53: exp((_b[_It0_1] +  _b[_It0Xuni_1_53])/_b[logpratio])) ///
(beta54: exp((_b[_It0_1] +  _b[_It0Xuni_1_54])/_b[logpratio])) ///
(beta55: exp((_b[_It0_1] +  _b[_It0Xuni_1_55])/_b[logpratio])) ///
(beta56: exp((_b[_It0_1] +  _b[_It0Xuni_1_56])/_b[logpratio])) ///
(beta57: exp((_b[_It0_1] +  _b[_It0Xuni_1_57])/_b[logpratio])) ///
(beta58: exp((_b[_It0_1] +  _b[_It0Xuni_1_58])/_b[logpratio])) ///
(beta59: exp((_b[_It0_1] +  _b[_It0Xuni_1_59])/_b[logpratio])) ///
(beta60: exp((_b[_It0_1] +  _b[_It0Xuni_1_60])/_b[logpratio])) ///
(beta61: exp((_b[_It0_1] +  _b[_It0Xuni_1_61])/_b[logpratio])) ///
(beta62: exp((_b[_It0_1] +  _b[_It0Xuni_1_62])/_b[logpratio])) ///
(beta63: exp((_b[_It0_1] +  _b[_It0Xuni_1_63])/_b[logpratio])) ///
(beta64: exp((_b[_It0_1] +  _b[_It0Xuni_1_64])/_b[logpratio])) ///
(beta65: exp((_b[_It0_1] +  _b[_It0Xuni_1_65])/_b[logpratio])) ///
(beta66: exp((_b[_It0_1] +  _b[_It0Xuni_1_66])/_b[logpratio])) ///
(beta67: exp((_b[_It0_1] +  _b[_It0Xuni_1_67])/_b[logpratio])) ///
(beta68: exp((_b[_It0_1] +  _b[_It0Xuni_1_68])/_b[logpratio])) ///
(beta69: exp((_b[_It0_1] +  _b[_It0Xuni_1_69])/_b[logpratio])) ///
(beta70: exp((_b[_It0_1] +  _b[_It0Xuni_1_70])/_b[logpratio])) ///
(beta71: exp((_b[_It0_1] +  _b[_It0Xuni_1_71])/_b[logpratio])) ///
(beta72: exp((_b[_It0_1] +  _b[_It0Xuni_1_72])/_b[logpratio])) ///
(beta73: exp((_b[_It0_1] +  _b[_It0Xuni_1_73])/_b[logpratio])) ///
(beta74: exp((_b[_It0_1] +  _b[_It0Xuni_1_74])/_b[logpratio])) ///
(beta75: exp((_b[_It0_1] +  _b[_It0Xuni_1_75])/_b[logpratio])) ///
(beta76: exp((_b[_It0_1] +  _b[_It0Xuni_1_76])/_b[logpratio])) ///
(beta77: exp((_b[_It0_1] +  _b[_It0Xuni_1_77])/_b[logpratio])) ///
(beta78: exp((_b[_It0_1] +  _b[_It0Xuni_1_78])/_b[logpratio])) ///
(beta79: exp((_b[_It0_1] +  _b[_It0Xuni_1_79])/_b[logpratio])) ///
(beta80: exp((_b[_It0_1] +  _b[_It0Xuni_1_80])/_b[logpratio])) ///
(beta81: exp((_b[_It0_1] +  _b[_It0Xuni_1_81])/_b[logpratio])) ///
(beta82: exp((_b[_It0_1] +  _b[_It0Xuni_1_82])/_b[logpratio])) ///
(beta83: exp((_b[_It0_1] +  _b[_It0Xuni_1_83])/_b[logpratio])) ///
(beta84: exp((_b[_It0_1] +  _b[_It0Xuni_1_84])/_b[logpratio])) ///
(beta85: exp((_b[_It0_1] +  _b[_It0Xuni_1_85])/_b[logpratio])) ///
(beta86: exp((_b[_It0_1] +  _b[_It0Xuni_1_86])/_b[logpratio])) ///
(beta87: exp((_b[_It0_1] +  _b[_It0Xuni_1_87])/_b[logpratio])) ///
(beta88: exp((_b[_It0_1] +  _b[_It0Xuni_1_88])/_b[logpratio])) ///
(beta89: exp((_b[_It0_1] +  _b[_It0Xuni_1_89])/_b[logpratio])) ///
(beta90: exp((_b[_It0_1] +  _b[_It0Xuni_1_90])/_b[logpratio])) ///
(beta91: exp((_b[_It0_1] +  _b[_It0Xuni_1_91])/_b[logpratio])) ///
(beta92: exp((_b[_It0_1] +  _b[_It0Xuni_1_92])/_b[logpratio])) ///
(beta93: exp((_b[_It0_1] +  _b[_It0Xuni_1_93])/_b[logpratio])) ///
(beta94: exp((_b[_It0_1] +  _b[_It0Xuni_1_94])/_b[logpratio])) ///
(beta95: exp((_b[_It0_1] +  _b[_It0Xuni_1_95])/_b[logpratio])) ///
(beta96: exp((_b[_It0_1] +  _b[_It0Xuni_1_96])/_b[logpratio])) ///
(beta97: exp((_b[_It0_1] +  _b[_It0Xuni_1_97])/_b[logpratio])) ///
(beta98: exp((_b[_It0_1] +  _b[_It0Xuni_1_98])/_b[logpratio])) ///
(beta99: exp((_b[_It0_1] +  _b[_It0Xuni_1_99])/_b[logpratio])) ///
(beta100: exp((_b[_It0_1] +  _b[_It0Xuni_1_100])/_b[logpratio])), post


forvalues i = 1(1)100 {
qui replace betai = _b[beta`i'] if uniqid == `i'
disp `i'
}





log on
/* Appendix Table A7-A8*/
capture drop uniqid
egen uniqid = group(id) if obscount==18 & attrit == 0 & money == 1 
capture drop uniqid2
egen uniqid2 = group(id) if obscount==18 & attrit == 0 & money == 0 

forvalues i = 1(1)99 {
estimates clear
return clear
qui su betai if  uniqid2 == `i' & money == 0
local workbeta = round(r(mean), .001)

qui su betai if  uniqid == `i' & money == 1
local moneybeta = round(r(mean), .001)

qui su bs if  uniqid2 == `i' & round == 1 & money == 0 
local workinit = round(r(mean), .001)

qui su bs if  uniqid2 == `i' & round == 2 & money == 0 
local worksub = round(r(mean), .001)

qui su bs if  uniqid == `i' & round == 1 & money == 1 
local moneyinit = round(r(mean), .001)

qui su bs if  uniqid == `i' & round == 2 & money == 1 
local moneysub = round(r(mean), .001)

disp `i' "&" `workinit' "&" `worksub' " & " `workbeta' "&" "&" `i' "&" `moneyinit' "&" `moneysub' " & " `moneybeta' "\\"
}
log off


log on






